package ru.vendetti.bitcoin_summarizer

//Репозиторий для обработки запросов
class CryptoRepository(private val apiService: CryptoApiService) {
    /**
     * Запрашивает данные для Bitcoin-тикера
     */
    suspend fun fetchBitcoinTicker(): TickerResponse? {
        return try {
            val response = apiService.getBitcoinTicker()
            if (response.isSuccessful) {
                response.body()
            } else {
                println("Ошибка запроса Bitcoin Ticker: ${response.code()}")
                null
            }
        } catch (e: Exception) {
            println("Exception при получении Bitcoin Ticker: ${e.localizedMessage}")
            null
        }
    }

    /**
     * Запрашивает глобальные данные крипторынка
     */
    suspend fun fetchGlobalData(): GlobalResponse? {
        return try {
            val response = apiService.getGlobalData()
            if (response.isSuccessful) {
                response.body()
            } else {
                println("Ошибка запроса Global Data: ${response.code()}")
                null
            }
        } catch (e: Exception) {
            println("Exception при получении Global Data: ${e.localizedMessage}")
            null
        }
    }

    /**
     * Запрашивает индекс страха и жадности за указанный период (по умолчанию 30 дней)
     */
    suspend fun fetchFearAndGreedData(limit: Int = 30): FearAndGreedResponse? {
        return try {
            val response = apiService.getFearAndGreedIndex(limit)
            if (response.isSuccessful) {
                response.body()
            } else {
                println("Ошибка запроса Fear & Greed Index: ${response.code()}")
                null
            }
        } catch (e: Exception) {
            println("Exception при получении Fear & Greed Index: ${e.localizedMessage}")
            null
        }
    }
}